<template>
  <div>
    <div id="sidebar">
      <recent-violations :violations="violations" />
      <suggestion-counter :suggestions="suggestions"/>
      <div id="headlines">
        <headlines />
      </div>
      <action-buttons
        :has-swiper="hasSwiper"
        :shop="shop" />
    </div>
    <div id="violations" class="clearfix">
      <div id="maincontent">
        <h1>Violations</h1>
        <section id="add-violation">
          <h2>Add Violation</h2>
          <ul class="errors"></ul>
          <form action="" method="">
            <div class="info clearfix">
              <div class="first-name">
                <label>First Name</label>
                <input type="text" name="firstName">
              </div>
              <div class="last-name">
                <label>Last Name</label>
                <input type="text" name="lastName">
              </div>
              <div class="account">
                <label>Account</label>
                <input v-model="form.accountId" type="text" name="account">
              </div>
            </div>
            <div id="docket">
          <!-- TODO: refactor this to take advantage of vue v-for more fully to capture fine amounts with the violation -->
              <table class="docket">
                <thead>
                  <tr>
                    <th><label>Law Broken</label></th>
                    <th><label>Verdict</label></th>
                  </tr>
                </thead>
                <tbody>
                  <template v-for="(newViolation, index) in form.charged_with">
                    <tr
                      :key="index"
                      :id="`docket${index}`">
                      <td>
                        <!-- the @change event will need to capture the violation.fine, and then set it as the value of the charged_with -->
                        <select
                          @change="captureFine(index)"
                          v-model="form.charged_with[index].violation"
                          class="docketSelect"
                          id="">
                          <option disabled value="">Please select a law</option>
                          <option
                            v-for="law in shop.laws"
                            :key="law.id"
                            :fine="2"
                            :value="law.body">{{ law.body }}
                          </option>
                        </select>
                      </td>
                      <td>
                        <input
                          v-model="form.charged_with[index].isGuilty"
                          @change="addUpFines"
                          type="radio"
                          :id="`guilty${index}-ng`"
                          :name="`guilty${index}`"
                          :value="false">
                        <label class="radio" :for="`guilty${index}-ng`"><span></span>Not Guilty
                        </label>
                        <input
                          v-model="form.charged_with[index].isGuilty"
                          @change="addUpFines"
                          type="radio"
                          :id="`guilty${index}-g`"
                          :name="`guilty${index}`"
                          :value="true"
                          checked="checked">
                        <label class="radio" :for="`guilty${index}-g`"><span></span>Guilty</label>
                      </td>
                    </tr>
                  </template>
                </tbody>
              </table>
              <!-- method that increments number of violations and also creates a new object in the form array, use of magic number is because I don't have access to index here... -->
              <a
                v-show="maxTenLawsBroken < 10"
                @click.prevent="createViolationObject()" class="another-docket">+ Create another violation?
              </a>
            </div>
            <div class="fine-and-submit">
              <div class="fine">
                <label>Fine Issued</label>
                <p>${{ fineTotal.toFixed(2) }}</p>
              </div>
              <div id="submit">
                <a @click="postForm" class="button submit">Save Violation</a>
              </div>
            </div>
          </form>
        </section>
        <section id="violations-list">
          <h2>List of Violations</h2>
          <input type="hidden" name="formId" value="violationsForm">
          <table class="violation-list">
            <thead>
              <tr>
                <th>Name</th>
                <th>Account</th>
                <th>Law Broken</th>
                <th>Fine</th>
              </tr>
            </thead>
            <tbody>
              <template v-for="(violator, index) in violations">
                <tr :key="index">
                  <td>{{ violator.account_name }}</td>
                  <td>{{ violator.account_id }}</td>
                  <td>
                    <p
                      v-for="(lawBroken, index) in violator.charged_with" :key="index">{{ lawBroken.violation }}
                    </p>
                  </td>
                  <td>${{ violator.fineTotal.toFixed(2) }}</td>
                </tr>

              </template>
            </tbody>
          </table>
        </section>
      </div>
    </div>
  </div>
</template>

<script>
import RecentViolations from "./components/RecentViolation.vue";
import SuggestionCounter from "./components/SuggestionCounter.vue";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";
export default {
  components: {
    RecentViolations,
    SuggestionCounter,
    Headlines,
    ActionButtons,
  },
  props: {
    suggestions: Array,
    violations: Array,
    shop: Object,
    hasSwiper: Boolean,
  },
  data() {
    return {
      // an array of violation objects with a uid that matches the index from the form
      // add button will add a new object to the data for
      form: {
        accountId: '',
        charged_with: [
          //array method to calculate the fine
          {
            index: 0,
            violation: '',
            isGuilty: false,
            fine: 0.00
          }
        ],
      },
      // TODO: need to get fine total
      fineTotal: 0,
      maxTenLawsBroken: 0
    }
  },
  methods: {
    postForm() {
      //remove any not guilty verdicts
      //TODO: move this to the API, where we just send all verdicts, and then when we want to get verdicts the API will filter on isGuilty
      const self = this;
      this.form.charged_with.map(function (violation, index) {
        if (violation.isGuilty == false) {
          self.form.charged_with.splice(index, 1)
        }
      });
      //send formatted data to API
      const data = this.form;
      console.log(data);

      app.session.SetSession()
        .then( () => {
          app.api.Post("townehall/postViolations/" + app.session.data.id, data)
            .then( Response => {
              console.log(Response);
              this.$emit('new-violation');
              // resets the violation form
              this.maxTenLawsBroken = 0;
              this.fineTotal = 0;
              this.form = {
                accountId: '',
                charged_with: [
                  {
                    index: 0,
                    violation: '',
                    isGuilty: false,
                    fine: 0.00,
                  }
                ],
              };
            })
            .catch( x => app.Message( x.error, "error" ));
        });
    },
    createViolationObject() {
      const index = this.form.charged_with.length;
      const newObject = {
        index: index,
        violation: '',
        isGuilty: false,
        fine: 0.00,
      };
      this.maxTenLawsBroken += 1;
      this.form.charged_with.push(newObject);
    },
    captureFine(index) {
      // const fineAmount = event.target.selectedOptions[0].attributes['0'].nodeValue;
      // this.form.charged_with[index].fine = parseFloat(fineAmount).toFixed(2);
      this.form.charged_with[index].fine = parseFloat(2).toFixed(2);
    },
    addUpFines() {
      const totalFines = [];
      const self = this;
      this.form.charged_with.map(function (violation, index) {
        if (violation.isGuilty === true && violation.fine) {
          totalFines.push(parseFloat(violation.fine));
          }
      })
      this.fineTotal = totalFines.reduce((acc, cv) => acc + cv, 0);
      console.log('added fines');

    }
  }
}
</script>

